# Python: Asynchronous Zophar's Domain Music Browser

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/zophar)
![PyPI - Version](https://img.shields.io/pypi/v/zophar)
![PyPI - Status](https://img.shields.io/pypi/status/zophar)
![PyPI - License](https://img.shields.io/pypi/l/zophar)
![PyPI - Downloads](https://img.shields.io/pypi/dm/zophar)

[![logo]](https://www.zophar.net/music)

## About

Simple asynchronous Python [Zophar's Domain Music](https://www.zophar.net/music) browser.

## Installation

```bash
pip install zophar
```

[logo]: https://www.zophar.net/images/header_logo_small.jpg "Zophar's Domain Music"